@@ -46,7 +46,6 @@ DolphinDetailsView::DolphinDetailsView(QWidget* parent, DolphinController* contr
     m_controller(controller),
     m_font(),
     m_decorationSize(),
-    m_clearAdditionalInfo(false),
     m_dragging(false),
     m_showElasticBand(false),
     m_elasticBandOrigin(),
@@ -102,7 +101,7 @@ DolphinDetailsView::DolphinDetailsView(QWidget* parent, DolphinController* contr
             this, SLOT(zoomIn()));
     connect(controller, SIGNAL(zoomOut()),
             this, SLOT(zoomOut()));
-    connect(controller->dolphinView(), SIGNAL(additionalInfoChanged(const KFileItemDelegate::InformationList&)),
+    connect(controller->dolphinView(), SIGNAL(additionalInfoChanged()),
             this, SLOT(updateColumnVisibility()));
 
     // apply the details mode settings to the widget
@@ -337,9 +336,15 @@ void DolphinDetailsView::keyPressEvent(QKeyEvent* event)
     const QModelIndex currentIndex = selModel->currentIndex();
     const bool trigger = currentIndex.isValid()
                          && (event->key() == Qt::Key_Return)
-                         && (selModel->selectedIndexes().count() <= 1);
-    if (trigger) {
-        triggerItem(currentIndex);
+                         && (selModel->selectedIndexes().count() > 0);
+    if(trigger) {
+        const QModelIndexList indexList = selModel->selectedIndexes();
+        foreach (const QModelIndex &index, indexList) {
+            KFileItem item = itemForIndex(index);
+            if (!item.isNull()) {
+                triggerItem(index);
+            }
+        }
     }
 }
 
@@ -357,20 +362,6 @@ void DolphinDetailsView::resizeEvent(QResizeEvent* event)
     }
 }
 
-void DolphinDetailsView::closeEvent(QCloseEvent* event)
-{
-    if (m_clearAdditionalInfo) {
-        disconnect(m_controller->dolphinView(), SIGNAL(additionalInfoChanged(const KFileItemDelegate::InformationList&)),
-                this, SLOT(updateColumnVisibility()));
-
-        KFileItemDelegate::InformationList info;
-        info.append(KFileItemDelegate::NoInformation);
-        m_controller->indicateAdditionalInfoChange(info);
-        m_clearAdditionalInfo = false;
-    }
-    QTreeView::closeEvent(event);
-}
-
 void DolphinDetailsView::setSortIndicatorSection(DolphinView::Sorting sorting)
 {
     QHeaderView* headerView = header();
@@ -497,27 +488,12 @@ void DolphinDetailsView::configureColumns(const QPoint& pos)
 
 void DolphinDetailsView::updateColumnVisibility()
 {
-    KFileItemDelegate::InformationList list = m_controller->dolphinView()->additionalInfo();
-    const bool useDefaultColumns = !isVisible() &&
-                                   (list.isEmpty() ||
-                                    list.contains(KFileItemDelegate::NoInformation));
-    if (useDefaultColumns) {
-        // Using the details view without any additional information (-> additional column)
-        // makes no sense and leads to a usability problem as no viewport area is available
-        // anymore. Hence as fallback provide at least a size and date column.
-        list.clear();
-        list.append(KFileItemDelegate::Size);
-        list.append(KFileItemDelegate::ModificationTime);
-        m_controller->indicateAdditionalInfoChange(list);
-        m_clearAdditionalInfo = true;
-    }
-
+    const KFileItemDelegate::InformationList list = m_controller->dolphinView()->additionalInfo();
     for (int i = DolphinModel::Size; i <= DolphinModel::Type; ++i) {
         const KFileItemDelegate::Information info = infoForColumn(i);
         const bool hide = !list.contains(info);
         if (isColumnHidden(i) != hide) {
             setColumnHidden(i, hide);
-            m_clearAdditionalInfo = false;
         }
     }
 
