@@ -46,7 +46,7 @@ DolphinPart::DolphinPart(QWidget* parentWidget, QObject* parent, const QStringLi
     : KParts::ReadOnlyPart(parent)
 {
     Q_UNUSED(args)
-    setComponentData( DolphinPartFactory::componentData() );
+    setComponentData(DolphinPartFactory::componentData(), false);
     m_extension = new DolphinPartBrowserExtension(this);
 
     // make sure that other apps using this part find Dolphin's view-file-columns icons
@@ -92,6 +92,8 @@ DolphinPart::DolphinPart(QWidget* parentWidget, QObject* parent, const QStringLi
             this, SLOT(slotRequestItemInfo(KFileItem)));
     connect(m_view, SIGNAL(urlChanged(KUrl)),
             this, SLOT(slotUrlChanged(KUrl)));
+    connect(m_view, SIGNAL(requestUrlChange(KUrl)),
+            this, SLOT(slotRequestUrlChange(KUrl)));
     connect(m_view, SIGNAL(modeChanged()),
             this, SIGNAL(viewModeChanged())); // relay signal
 
@@ -110,6 +112,8 @@ DolphinPart::DolphinPart(QWidget* parentWidget, QObject* parent, const QStringLi
 
     // TODO there was a "always open a new window" (when clicking on a directory) setting in konqueror
     // (sort of spacial navigation)
+
+    loadPlugins(this, this, componentData());
 }
 
 DolphinPart::~DolphinPart()
@@ -217,6 +221,7 @@ bool DolphinPart::openUrl(const KUrl& url)
     emit m_extension->setLocationBarUrl(prettyUrl);
     emit started(0); // get the wheel to spin
     m_view->setUrl(url);
+    emit aboutToOpenURL();
     if (reload)
         m_view->reload();
     return true;
@@ -341,6 +346,12 @@ void DolphinPart::slotOpenContextMenu(const KFileItem& _item, const KUrl&)
 }
 
 void DolphinPart::slotUrlChanged(const KUrl& url)
+{
+    QString prettyUrl = url.pathOrUrl();
+    emit m_extension->setLocationBarUrl(prettyUrl);
+}
+
+void DolphinPart::slotRequestUrlChange(const KUrl& url)
 {
     if (m_view->url() != url) {
         // If the view URL is not equal to 'url', then an inner URL change has
