@@ -89,6 +89,12 @@ Q_SIGNALS:
      */
     void viewModeChanged();
 
+    /**
+     * Emitted whenever the current URL is about to be changed.
+     */
+    void aboutToOpenURL();
+
+
 private Q_SLOTS:
     void slotCompleted(const KUrl& url);
     void slotCanceled(const KUrl& url);
@@ -115,6 +121,11 @@ private Q_SLOTS:
      * Asks the host to open the URL \a url if the current view has
      * a different URL.
      */
+    void slotRequestUrlChange(const KUrl& url);
+
+    /**
+     * Informs the host that we are opening \a url (e.g. after a redirection).
+     */
     void slotUrlChanged(const KUrl& url);
 
     /**
