@@ -67,6 +67,7 @@ DolphinView::DolphinView(QWidget* parent,
     m_showPreview(false),
     m_loadingDirectory(false),
     m_storedCategorizedSorting(false),
+    m_isContextMenuOpen(false),
     m_mode(DolphinView::IconsView),
     m_topLayout(0),
     m_controller(0),
@@ -104,7 +105,7 @@ DolphinView::DolphinView(QWidget* parent,
     connect(m_controller, SIGNAL(urlChanged(const KUrl&)),
             this, SIGNAL(urlChanged(const KUrl&)));
     connect(m_controller, SIGNAL(requestUrlChange(const KUrl&)),
-            this, SIGNAL(urlChanged(const KUrl&)));
+            this, SLOT(slotRequestUrlChange(const KUrl&)));
 
     connect(m_controller, SIGNAL(requestContextMenu(const QPoint&)),
             this, SLOT(openContextMenu(const QPoint&)));
@@ -125,6 +126,9 @@ DolphinView::DolphinView(QWidget* parent,
     connect(m_controller, SIGNAL(viewportEntered()),
             this, SLOT(clearHoverInformation()));
 
+    connect(m_dirLister, SIGNAL(redirection(KUrl, KUrl)),
+            this, SLOT(slotRedirection(KUrl, KUrl)));
+
     applyViewProperties(url);
     m_topLayout->addWidget(itemView());
 }
@@ -568,7 +572,8 @@ void DolphinView::triggerItem(const KFileItem& item)
         return;
     }
 
-    if (item.isNull()) {
+    // TODO: the m_isContextMenuOpen check is a workaround for Qt-issue xxxxxx
+    if (item.isNull() || m_isContextMenuOpen) {
         return;
     }
 
@@ -748,7 +753,9 @@ void DolphinView::openContextMenu(const QPoint& pos)
         item = fileItem(index);
     }
 
+    m_isContextMenuOpen = true; // TODO: workaround for Qt-issue xxxxxx
     emit requestContextMenu(item, url());
+    m_isContextMenuOpen = false;
 }
 
 void DolphinView::dropUrls(const KUrl::List& urls,
@@ -1258,4 +1265,16 @@ QPair<bool, QString> DolphinView::pasteInfo() const
     return ret;
 }
 
+void DolphinView::slotRequestUrlChange(const KUrl& url)
+{
+    emit requestUrlChange(url);
+    m_controller->setUrl(url);
+}
+
+void DolphinView::slotRedirection(const KUrl& oldUrl, const KUrl& newUrl)
+{
+    if (oldUrl == m_controller->url())
+        m_controller->setUrl(newUrl);
+}
+
 #include "dolphinview.moc"
