@@ -403,6 +403,12 @@ signals:
     /** Is emitted if URL of the view has been changed to \a url. */
     void urlChanged(const KUrl& url);
 
+    /**
+     * Is emitted if the view requests a changing of the current
+     * URL to \a url (see DolphinController::triggerUrlChangeRequest()).
+     */
+    void requestUrlChange(const KUrl& url);
+
     /**
      * Is emitted when clicking on an item
      */
@@ -593,6 +599,18 @@ private slots:
      */
     void slotPreviewJobFinished(KJob* job);
 
+    /**
+     * Called when KDirLister emits redirection.
+     * Testcase: fish://localhost
+     */
+    void slotRedirection(const KUrl& oldUrl, const KUrl& newUrl);
+
+    /**
+     * Is emitted if the controller requests a changing of the current
+     * URL to \a url
+     */
+    void slotRequestUrlChange(const KUrl& url);
+
 private:
     void loadDirectory(const KUrl& url, bool reload = false);
 
@@ -659,6 +677,7 @@ private:
     bool m_showPreview;
     bool m_loadingDirectory;
     bool m_storedCategorizedSorting;
+    bool m_isContextMenuOpen;   // TODO: workaround for Qt-issue xxxxxx
     Mode m_mode;
 
     DolphinMainWindow* m_mainWindow;
