@@ -305,31 +305,39 @@ void KonqView::switchView( KonqViewFactory &viewFactory )
   }
 }
 
-bool KonqView::changeViewMode( const QString &serviceType,
-                               const QString &serviceName,
-                               bool forceAutoEmbed )
+bool KonqView::ensureViewSupports( const QString &mimeType,
+                                   bool forceAutoEmbed )
 {
-  // Caller should call stop first.
-  assert ( !m_bLoading );
+    if (supportsMimeType(mimeType))
+        return true;
+    return changePart(mimeType, QString(), forceAutoEmbed);
+}
 
-  kDebug(1202) << "changeViewMode: serviceType is " << serviceType
-                << " serviceName is " << serviceName
-                << " current service name is " << m_service->desktopEntryName() << endl;
+bool KonqView::changePart(const QString &mimeType,
+                          const QString &serviceName,
+                          bool forceAutoEmbed)
+{
+    // Caller should call stop first.
+    assert( !m_bLoading );
 
-  if ( KMimeType::mimeType(serviceType) && KMimeType::mimeType(serviceType)->is(m_serviceType) && (serviceName.isEmpty() || serviceName == m_service->desktopEntryName()) )
-    return true;
+    //kDebug(1202) << "mimeType=" << mimeType
+    //             << "requested serviceName=" << serviceName
+    //             << "current service name=" << m_service->desktopEntryName();
 
-  if ( isLockedViewMode() )
-  {
-    //kDebug(1202) << "This view's mode is locked - can't change";
-    return false; // we can't do that if our view mode is locked
-  }
+    if (serviceName == m_service->desktopEntryName()) {
+        m_serviceType = mimeType;
+        return true;
+    }
 
-  kDebug(1202) << "Switching view modes...";
-  KService::List partServiceOffers, appServiceOffers;
-  KService::Ptr service;
-  KonqFactory konqFactory;
-  KonqViewFactory viewFactory = konqFactory.createView( serviceType, serviceName, &service, &partServiceOffers, &appServiceOffers, forceAutoEmbed );
+    if (isLockedViewMode()) {
+        //kDebug(1202) << "This view's mode is locked - can't change";
+        return false; // we can't do that if our view mode is locked
+    }
+
+    KService::List partServiceOffers, appServiceOffers;
+    KService::Ptr service;
+    KonqFactory konqFactory;
+    KonqViewFactory viewFactory = konqFactory.createView( mimeType, serviceName, &service, &partServiceOffers, &appServiceOffers, forceAutoEmbed );
 
   if ( viewFactory.isNull() )
   {
@@ -339,12 +347,12 @@ bool KonqView::changeViewMode( const QString &serviceType,
     return false;
   }
 
-  m_serviceType = serviceType;
+  m_serviceType = mimeType;
   m_partServiceOffers = partServiceOffers;
   m_appServiceOffers = appServiceOffers;
 
   // Check if that's already the kind of part we have -> no need to recreate it
-  // Note: we should have an operator= for KService...
+  // Note: we should have an operator== for KService...
   if ( m_service && m_service->entryPath() == service->entryPath() )
   {
     kDebug( 1202 ) << "KonqView::changeViewMode. Reusing service. Service type set to " << m_serviceType;
@@ -371,7 +379,7 @@ bool KonqView::changeViewMode( const QString &serviceType,
   return true;
 }
 
-void KonqView::connectPart(  )
+void KonqView::connectPart()
 {
   //kDebug(1202) << "KonqView::connectPart";
   connect( m_pPart, SIGNAL( started( KIO::Job * ) ),
@@ -384,6 +392,11 @@ void KonqView::connectPart(  )
            this, SLOT( slotCanceled( const QString & ) ) );
   connect( m_pPart, SIGNAL( setWindowCaption( const QString & ) ),
            this, SLOT( setCaption( const QString & ) ) );
+  if (!internalViewMode().isEmpty()) {
+      // Update checked action in "View Mode" menu when switching view mode in dolphin
+      connect(m_pPart, SIGNAL(viewModeChanged()),
+              m_pMainWindow, SLOT(slotInternalViewModeChanged()));
+  }
 
   KParts::BrowserExtension *ext = browserExtension();
 
@@ -597,7 +610,7 @@ void KonqView::slotCompleted( bool hasPending )
     if ( KonqSettings::enableFavicon() == true )
     {
       // Try to get /favicon.ico
-      if ( supportsServiceType( "text/html" ) && url().protocol().startsWith( "http" ) )
+      if ( supportsMimeType( "text/html" ) && url().protocol().startsWith( "http" ) )
           KonqPixmapProvider::self()->downloadHostIcon( url().url() );
     }
   }
@@ -790,9 +803,8 @@ void KonqView::go( int steps )
   int newPos = historyIndex() + steps;
 #ifdef DEBUG_HISTORY
   kDebug(1202) << "go : steps=" << steps
-                << " newPos=" << newPos
-                << " m_lstHistory.count()=" << m_lstHistory.count()
-                << endl;
+               << " newPos=" << newPos
+               << " m_lstHistory.count()=" << m_lstHistory.count();
 #endif
   if( newPos < 0 || newPos >= m_lstHistory.count() )
     return;
@@ -819,12 +831,11 @@ void KonqView::restoreHistory()
   setLocationBarURL( h.locationBarURL );
   setPageSecurity( h.pageSecurity );
   m_sTypedURL.clear();
-  if ( ! changeViewMode( h.strServiceType, h.strServiceName ) )
-  {
-    kWarning(1202) << "Couldn't change view mode to " << h.strServiceType
-                    << " " << h.strServiceName << endl;
-    return /*false*/;
-  }
+
+    if (!changePart(h.strServiceType, h.strServiceName)) {
+        kWarning(1202) << "Couldn't change view mode to" << h.strServiceType << h.strServiceName;
+        return /*false*/;
+    }
 
   setPartMimeType();
 
@@ -1171,7 +1182,7 @@ QString KonqView::dbusObjectPath()
     // And to make sure it's a valid dbus object path like in kmainwindow...
     static int s_viewNumber = 0;
     if ( m_dbusObjectPath.isEmpty() ) {
-        m_dbusObjectPath = '/' + m_pMainWindow->objectName() + '/' + QString::number( ++s_viewNumber );
+        m_dbusObjectPath = m_pMainWindow->dbusName() + '/' + QString::number( ++s_viewNumber );
         new KonqViewAdaptor( this );
         QDBusConnection::sessionBus().registerObject( m_dbusObjectPath, this );
     }
@@ -1314,15 +1325,14 @@ KParts::StatusBarExtension * KonqView::statusBarExtension() const
     return KParts::StatusBarExtension::childObject( m_pPart );
 }
 
-bool KonqView::supportsServiceType( const QString &serviceType ) const
+bool KonqView::supportsMimeType( const QString &mimeType ) const
 {
+    KMimeType::Ptr mime = KMimeType::mimeType( mimeType );
+    if (!mime)
+        return false;
     const QStringList lst = serviceTypes();
     for( QStringList::ConstIterator it = lst.begin(); it != lst.end(); ++it ) {
-        if ( *it == serviceType )
-            return true;
-        // Maybe we should keep around a list of KServiceType::Ptr?
-        KMimeType::Ptr mime = KMimeType::mimeType( *it );
-        if ( mime && mime->is( serviceType ) ) // respect inheritance
+        if ( mime->is(*it) ) // same as mime == *it, but also respect inheritance, mimeType can be a subclass
             return true;
     }
     return false;
@@ -1370,7 +1380,8 @@ void KonqView::saveConfig( KConfigGroup& config, const QString &prefix, const Ko
     if (options & KonqFrameBase::saveURLs) {
         config.writePathEntry( QString::fromLatin1( "URL" ).prepend( prefix ), url().url() );
     } else if(options & KonqFrameBase::saveHistoryItems) {
-        updateHistoryEntry(true);
+        if (m_pPart)
+            updateHistoryEntry(true);
         QList<HistoryEntry*>::Iterator it = m_lstHistory.begin();
         for ( uint i = 0; it != m_lstHistory.end(); ++it, ++i ) {
             (*it)->saveConfig(config, QString::fromLatin1( "HistoryItem" ) + QString::number(i).prepend( prefix ));
@@ -1409,4 +1420,15 @@ void KonqView::loadHistoryConfig(const KConfigGroup& config, const QString &pref
 }
 
 
+QString KonqView::internalViewMode() const
+{
+    const QVariant viewModeProperty = m_pPart->property("currentViewMode");
+    return viewModeProperty.toString();
+}
+
+void KonqView::setInternalViewMode(const QString& viewMode)
+{
+    m_pPart->setProperty("currentViewMode", viewMode);
+}
+
 #include "konqview.moc"
