@@ -386,6 +386,8 @@ public:
     /** Returns the terminal screen section which is displayed in this widget.  See setScreenWindow() */
     ScreenWindow* screenWindow() const;
 
+    static bool HAVE_TRANSPARENCY;
+
 public slots:
 
     /** 
@@ -614,6 +616,9 @@ private:
 	// a hotspot
 	QRegion hotSpotRegion() const;
 
+	// returns the position of the cursor in columns and lines
+	QPoint cursorPosition() const;
+
     // the window onto the terminal screen which this display
     // is currently showing.  
     QPointer<ScreenWindow> _screenWindow;
@@ -691,8 +696,7 @@ private:
                                // after QApplication::doubleClickInterval() delay
 
 
-    QFrame* _resizeWidget;
-    QLabel* _resizeLabel;
+    QLabel* _resizeWidget;
     QTimer* _resizeTimer;
 
 	bool _flowControlWarningEnabled;
@@ -728,7 +732,6 @@ private:
     };
     InputMethodData _inputMethodData;
 
-    static bool HAVE_TRANSPARENCY;
     static bool _antialiasText;   // do we antialias or not
 
     //the delay in milliseconds between redrawing blinking text
